Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(121)

Unified Diff: net/filter/filter.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/filter/filter.h
diff --git a/net/filter/filter.h b/net/filter/filter.h
index 1940399e06806095796380a91054db20186e7837..05a314bd3c215d6ba7bb477940c5d35c8b1a0a3a 100644
--- a/net/filter/filter.h
+++ b/net/filter/filter.h
@@ -63,7 +63,7 @@ class GURL;
namespace net {
-class BoundNetLog;
+class NetLogWithSource;
class IOBuffer;
class URLRequestContext;
@@ -128,8 +128,8 @@ class NET_EXPORT_PRIVATE FilterContext {
// statistics as selected by the argument.
virtual void RecordPacketStats(StatisticSelector statistic) const = 0;
- // The BoundNetLog of the associated request.
- virtual const BoundNetLog& GetNetLog() const = 0;
+ // The NetLogWithSource of the associated request.
+ virtual const NetLogWithSource& GetNetLog() const = 0;
};
//------------------------------------------------------------------------------

Powered by Google App Engine
This is Rietveld 408576698